@@ -29,6 +29,8 @@ test_that("Columns with dates are standardized", {
 })
 
 test_that("dataset is arranged by date variable", {
+  skip_on_ci()
+  skip_on_cran()
   if (!is.null(emperors[["UNRV"]]$Begin)) {
     expect_true(emperors[["UNRV"]]$Begin[10] < emperors[["UNRV"]]$Begin[20])
   }
